@@ -1,8 +1,7 @@
 #
 # exceptions.py
 #
-# Copyright (C) 2017 frnmst (Franco Masotti) <franco.masotti@live.com>
-#                                            <franco.masotti@student.unife.it>
+# Copyright (C) 2017-2020 frnmst (Franco Masotti) <franco.masotti@live.com>
 #
 # This file is part of fpyutils.
 #
@@ -28,3 +27,7 @@ class LineOutOfFileBoundsError(Exception):
     Raises an exception if there was an attempt to access a non-existing line
     in a file.
     """
+
+
+class NegativeLineRangeError(Exception):
+    """Line range does not make sense."""
